@@ -118,7 +118,7 @@ def is_schema_valid(types, modes, names, values):
             try:
                 value = value.strip()
                 if len(value) > 23:
-                    datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f+00:00")
+                    pass
                 if len(value) > 19: # check to see if microseconds are in date
                     datetime.strptime(value, "%Y-%m-%d %H:%M:%S.%f")
                 else:
